@@ -62,21 +62,21 @@ template<typename T> float get_FA(const T& val1, const T& val2, const T& val3) {
 
 // Insert an ellipsoid in a CImg 3D scene
 //----------------------------------------
-template<typename t,typename tp,typename tf,typename tc>
-void insert_ellipsoid(const CImg<t>& tensor,const float X,const float Y,const float Z,const float tfact,
+template<typename t, typename tp, typename tf, typename tc>
+void insert_ellipsoid(const CImg<t>& tensor, const float X, const float Y, const float Z, const float tfact,
                       const float vx, const float vy, const float vz,
                       CImgList<tp>& points, CImgList<tf>& faces, CImgList<tc>& colors,
-                      const unsigned int res1 = 20, const unsigned int res2 = 20) {
+                      const unsigned int res1=20, const unsigned int res2=20) {
 
   // Compute eigen elements
-  const float l1 = tensor[0], l2 = tensor[1], l3 = tensor[2], fa = get_FA(l1,l2,l3);
+  float l1 = tensor[0], l2 = tensor[1], l3 = tensor[2], fa = get_FA(l1,l2,l3);
   CImg<> vec = CImg<>::matrix(tensor[3],tensor[6],tensor[9],
                               tensor[4],tensor[7],tensor[10],
                               tensor[5],tensor[8],tensor[11]);
   const int
-    r = (int)cimg::min(30+1.5f*cimg::abs(255*fa*tensor[3]),255.0f),
-    g = (int)cimg::min(30+1.5f*cimg::abs(255*fa*tensor[4]),255.0f),
-    b = (int)cimg::min(30+1.5f*cimg::abs(255*fa*tensor[5]),255.0f);
+    r = (int)cimg::min(30 + 1.5f*cimg::abs(255*fa*tensor[3]),255.0f),
+    g = (int)cimg::min(30 + 1.5f*cimg::abs(255*fa*tensor[4]),255.0f),
+    b = (int)cimg::min(30 + 1.5f*cimg::abs(255*fa*tensor[5]),255.0f);
 
   // Define mesh points
   const unsigned int N0 = points.size();
@@ -88,24 +88,24 @@ void insert_ellipsoid(const CImg<t>& tensor,const float X,const float Y,const fl
         x = (float)(tfact*l1*std::cos(beta)*std::cos(alpha)),
         y = (float)(tfact*l2*std::cos(beta)*std::sin(alpha)),
         z = (float)(tfact*l3*std::sin(beta));
-      points.insert((CImg<tp>::vector(X,Y,Z)+vec*CImg<tp>::vector(x,y,z)).mul(CImg<tp>::vector(vx,vy,vz)));
+      points.insert((CImg<tp>::vector(X,Y,Z) + vec*CImg<tp>::vector(x,y,z)).mul(CImg<tp>::vector(vx,vy,vz)));
     }
   const unsigned int N1 = points.size();
-  points.insert((CImg<tp>::vector(X,Y,Z)+vec*CImg<tp>::vector(0,0,-l3*tfact)));
-  points.insert((CImg<tp>::vector(X,Y,Z)+vec*CImg<tp>::vector(0,0,l3*tfact)));
+  points.insert((CImg<tp>::vector(X,Y,Z) - vec*CImg<tp>::vector(0,0,l3*tfact)));
+  points.insert((CImg<tp>::vector(X,Y,Z) + vec*CImg<tp>::vector(0,0,l3*tfact)));
   points[points.size()-2](0)*=vx; points[points.size()-2](1)*=vy; points[points.size()-2](2)*=vz;
   points[points.size()-1](0)*=vx; points[points.size()-1](1)*=vy; points[points.size()-1](2)*=vz;
 
   // Define mesh triangles
-  for (unsigned int vv=0; vv<res2-2; vv++)
-    for (unsigned int uu=0; uu<res1; uu++) {
+  for (unsigned int vv = 0; vv<res2-2; ++vv)
+    for (unsigned int uu = 0; uu<res1; ++uu) {
       const int nv = (vv+1)%(res2-1), nu = (uu+1)%res1;
       faces.insert(CImg<tf>::vector(N0+res1*vv+nu,N0+res1*nv+uu,N0+res1*vv+uu));
       faces.insert(CImg<tf>::vector(N0+res1*vv+nu,N0+res1*nv+nu,N0+res1*nv+uu));
       colors.insert(CImg<tc>::vector(r,g,b));
       colors.insert(CImg<tc>::vector(r,g,b));
     }
-  for (unsigned int uu=0; uu<res1; uu++) {
+  for (unsigned int uu = 0; uu<res1; ++uu) {
     const int nu = (uu+1)%res1;
     faces.insert(CImg<tf>::vector(N0+nu,N0+uu,N1));
     faces.insert(CImg<tf>::vector(N0+res1*(res2-2)+nu, N1+1,N0+res1*(res2-2)+uu));
@@ -124,7 +124,7 @@ void insert_fiber(const CImg<T>& fiber, const CImg<te>& eigen, const CImg<tc>& p
   const int N0 = points.size();
   float x0 = fiber(0,0), y0 = fiber(0,1), z0 = fiber(0,2), fa0 = eigen.linear_atXYZ(x0,y0,z0,12);
   points.insert(CImg<>::vector(vx*(x0-xm),vy*(y0-ym),vz*(z0-zm)));
-  for (int l=1; l<fiber.width(); l++) {
+  for (int l = 1; l<fiber.width(); ++l) {
     float x1 = fiber(l,0), y1 = fiber(l,1), z1 = fiber(l,2), fa1 = eigen.linear_atXYZ(x1,y1,z1,12);
     points.insert(CImg<tp>::vector(vx*(x1-xm),vy*(y1-ym),vz*(z1-zm)));
     primitives.insert(CImg<tf>::vector(N0+l-1,N0+l));
@@ -134,7 +134,7 @@ void insert_fiber(const CImg<T>& fiber, const CImg<te>& eigen, const CImg<tc>& p
       g = palette(icol,1),
       b = palette(icol,2);
     colors.insert(CImg<unsigned char>::vector(r,g,b));
-    x0=x1; y0=y1; z0=z1; fa0=fa1;
+    x0 = x1; y0 = y1; z0 = z1; fa0 = fa1;
   }
 }
 
@@ -143,10 +143,10 @@ void insert_fiber(const CImg<T>& fiber, const CImg<te>& eigen, const CImg<tc>& p
 template<typename T>
 CImg<> get_fibertrack(CImg<T>& eigen,
                       const int X0, const int Y0, const int Z0, const float lmax=100,
-                      const float dl = 0.1f, const float FAmin=0.7f, const float cmin=0.5f) {
+                      const float dl=0.1f, const float FAmin=0.7f, const float cmin=0.5f) {
 #define align_eigen(i,j,k) \
-      { T &u = eigen(i,j,k,3), &v = eigen(i,j,k,4), &w = eigen(i,j,k,5); \
-        if (u*cu+v*cv+w*cw<0) { u=-u; v=-v; w=-w; }}
+  { T &u = eigen(i,j,k,3), &v = eigen(i,j,k,4), &w = eigen(i,j,k,5); \
+    if (u*cu+v*cv+w*cw<0) { u=-u; v=-v; w=-w; }}
 
   CImgList<> resf;
 
@@ -156,7 +156,7 @@ CImg<> get_fibertrack(CImg<T>& eigen,
     pu = eigen(X0,Y0,Z0,3),
     pv = eigen(X0,Y0,Z0,4),
     pw = eigen(X0,Y0,Z0,5);
-  normpU = (float)std::sqrt(pu*pu+pv*pv+pw*pw);
+  normpU = (float)std::sqrt(pu*pu + pv*pv + pw*pw);
   bool stopflag = false;
 
   while (!stopflag) {
@@ -198,9 +198,9 @@ CImg<> get_fibertrack(CImg<T>& eigen,
         u = u0/3 + 2*u1/3 + 2*u2/3 + u3/3,
         v = v0/3 + 2*v1/3 + 2*v2/3 + v3/3,
         w = w0/3 + 2*w1/3 + 2*w2/3 + w3/3;
-      if (u*pu+v*pv+w*pw<0) { u=-u; v=-v; w=-w; }
-      normU = (float)std::sqrt(u*u+v*v+w*w);
-      const float scal = (u*pu+v*pv+w*pw)/(normU*normpU);
+      if (u*pu + v*pv + w*pw<0) { u = -u; v = -v; w = -w; }
+      normU = (float)std::sqrt(u*u + v*v + w*w);
+      const float scal = (u*pu + v*pv + w*pw)/(normU*normpU);
       if (scal<cmin) stopflag=true;
 
       X+=(pu=u); Y+=(pv=v); Z+=(pw=w);
@@ -214,7 +214,7 @@ CImg<> get_fibertrack(CImg<T>& eigen,
   pu = eigen(X0,Y0,Z0,3);
   pv = eigen(X0,Y0,Z0,4);
   pw = eigen(X0,Y0,Z0,5);
-  normpU = (float)std::sqrt(pu*pu+pv*pv+pw*pw);
+  normpU = (float)std::sqrt(pu*pu + pv*pv + pw*pw);
   stopflag = false;
 
   while (!stopflag) {
@@ -255,9 +255,9 @@ CImg<> get_fibertrack(CImg<T>& eigen,
         u = u0/3 + 2*u1/3 + 2*u2/3 + u3/3,
         v = v0/3 + 2*v1/3 + 2*v2/3 + v3/3,
         w = w0/3 + 2*w1/3 + 2*w2/3 + w3/3;
-      if (u*pu+v*pv+w*pw<0) { u=-u; v=-v; w=-w; }
-      normU = (float)std::sqrt(u*u+v*v+w*w);
-      const float scal = (u*pu+v*pv+w*pw)/(normU*normpU);
+      if (u*pu + v*pv + w*pw<0) { u = -u; v = -v; w = -w; }
+      normU = (float)std::sqrt(u*u + v*v + w*w);
+      const float scal = (u*pu + v*pv + w*pw)/(normU*normpU);
       if (scal<cmin) stopflag=true;
 
       X-=(pu=u); Y-=(pv=v); Z-=(pw=w);
@@ -289,7 +289,7 @@ int main(int argc,char **argv) {
   const float lmax     = cimg_option("-lmax",1000.0f,"Fiber computation : Maximum length\n");
   const float tfact    = cimg_option("-tfact",1.2f,"Display : Tensor size factor");
   const char *bgcolor  = cimg_option("-bg","0,0,0","Display : Background color");
-  unsigned int bgr=0, bgg=0, bgb=0;
+  unsigned int bgr = 0, bgg = 0, bgb = 0;
   std::sscanf(bgcolor,"%u%*c%u%*c%u",&bgr,&bgg,&bgb);
 
   CImg<> tensors;
@@ -300,13 +300,12 @@ int main(int argc,char **argv) {
     // Create a synthetic tensor field here
     std::fprintf(stderr,"\n- No input files : Creating a synthetic tensor field");
     tensors.assign(32,32,32,6);
-    const CImg<> Id = CImg<>::diagonal(0.3f,0.3f,0.3f);
     cimg_forXYZ(tensors,x,y,z) {
       const float
-        u = x-tensors.width()/2.0f,
-        v = y-tensors.height()/2.0f,
-        w = z-tensors.depth()/2.0f,
-        norm = (float)std::sqrt(1e-5f+u*u+v*v+w*w),
+        u = x - tensors.width()/2.0f,
+        v = y - tensors.height()/2.0f,
+        w = z - tensors.depth()/2.0f,
+        norm = (float)std::sqrt(1e-5f + u*u + v*v + w*w),
         nu = u/norm, nv = v/norm, nw = w/norm;
       const CImg<>
         dir1 = CImg<>::vector(nu,nv,nw),
@@ -318,14 +317,13 @@ int main(int argc,char **argv) {
                             x,y,z);
     }
   }
-  float voxw=1,voxh=1,voxd=1;
+  float voxw = 1, voxh = 1, voxd = 1;
   std::sscanf(vsize,"%f%*c%f%*c%f",&voxw,&voxh,&voxd);
 
   std::fprintf(stderr," : %ux%ux%u image, voxsize=%gx%gx%g.",
                tensors.width(),tensors.height(),tensors.depth(),
                voxw,voxh,voxd);
 
-
   CImgList<> fibers;
   if (file_f) {
     std::fprintf(stderr,"\n- Loading fibers '%s'.",cimg::basename(file_f));
@@ -345,9 +343,9 @@ int main(int argc,char **argv) {
   cimg_forXYZ(tensors,x,y,z) {
     tensors.get_tensor_at(x,y,z).symmetric_eigen(val,vec);
     eigen(x,y,z,0) = val[0]; eigen(x,y,z,1) = val[1]; eigen(x,y,z,2) = val[2];
-    if (val[0]<0) val[0]=0;
-    if (val[1]<0) val[1]=0;
-    if (val[2]<0) val[2]=0;
+    if (val[0]<0) val[0] = 0;
+    if (val[1]<0) val[1] = 0;
+    if (val[2]<0) val[2] = 0;
     if (val[0]>eigmax) eigmax = val[0];
     eigen(x,y,z,3) = vec(0,0); eigen(x,y,z,4)  = vec(0,1); eigen(x,y,z,5)  = vec(0,2);
     eigen(x,y,z,6) = vec(1,0); eigen(x,y,z,7)  = vec(1,1); eigen(x,y,z,8)  = vec(1,2);
@@ -383,13 +381,13 @@ int main(int argc,char **argv) {
 
       // Open 3D visualization window
       //-----------------------------
-    case cimg::keyA:
-    case 0: {
-      const unsigned char white[1] = { 255 };
+    case cimg::keyA :
+    case 0 : {
+      const unsigned char white[] = { 255 };
       disp3d.display(CImg<unsigned char>(disp3d.width(),disp3d.height(),1,1,0).draw_text(10,10,"Please wait...",white)).show();
       int xm,ym,zm,xM,yM,zM;
       if (!disp.key()) { xm = s[0]; ym = s[1]; zm = s[2]; xM = s[3]; yM = s[4]; zM = s[5]; }
-      else { xm = ym = zm = 0; xM = eigen.width()-1; yM = eigen.height()-1; zM = eigen.height()-1; }
+      else { xm = ym = zm = 0; xM = eigen.width() - 1; yM = eigen.height() - 1; zM = eigen.height() - 1; }
       const CImg<> img = eigen.get_crop(xm,ym,zm,xM,yM,zM);
       CImgList<> points;
       CImgList<unsigned int> primitives;
@@ -418,7 +416,7 @@ int main(int argc,char **argv) {
         visu.display_object3d(disp3d,pts,primitives,colors,true,4,-1,false,800,0.05f,1.0f);
         disp3d.close();
         switch (disp3d.key()) {
-        case cimg::keyM: { // Create movie
+        case cimg::keyM : { // Create movie
           std::fprintf(stderr,"\n- Movie mode.\n");
           const unsigned int N = 256;
           CImg<> cpts(pts);
@@ -453,7 +451,7 @@ int main(int argc,char **argv) {
 
     // Compute region statistics
     //---------------------------
-    case cimg::keyR: {
+    case cimg::keyR : {
       std::fprintf(stderr,"\n- Statistics computation. Select region."); std::fflush(stderr);
       const CImg<int> s = coloredFA.get_select(disp,2,XYZ);
       int xm, ym, zm, xM, yM, zM;
@@ -467,7 +465,7 @@ int main(int argc,char **argv) {
 
     // Track fiber bundle (single region)
     //----------------------------------
-    case cimg::keyF: {
+    case cimg::keyF : {
       std::fprintf(stderr,"\n- Tracking mode (single region). Select starting region.\n"); std::fflush(stderr);
       const CImg<int> s = coloredFA.get_select(disp,2,XYZ);
       const unsigned int N = fibers.size();
@@ -485,7 +483,7 @@ int main(int argc,char **argv) {
 
     // Track fiber bundle (double regions)
     //------------------------------------
-    case cimg::keyG: {
+    case cimg::keyG : {
       std::fprintf(stderr,"\n- Tracking mode (double region). Select starting region."); std::fflush(stderr);
       const CImg<int> s = coloredFA.get_select(disp,2,XYZ);
       std::fprintf(stderr," Select ending region."); std::fflush(stderr);
@@ -493,9 +491,9 @@ int main(int argc,char **argv) {
       const unsigned int N = fibers.size();
 
       // Track from start to end
-      for (int z=s[2]; z<=s[5]; z++)
-        for (int y=s[1]; y<=s[4]; y++)
-          for (int x=s[0]; x<=s[3]; x++) {
+      for (int z = s[2]; z<=s[5]; ++z)
+        for (int y = s[1]; y<=s[4]; ++y)
+          for (int x = s[0]; x<=s[3]; ++x) {
             const CImg<> fiber = get_fibertrack(eigen,x,y,z,lmax,dl,famin,cmin);
             if (fiber.width()>lmin) {
               bool valid_fiber = false;
@@ -510,9 +508,9 @@ int main(int argc,char **argv) {
           }
 
       // Track from end to start
-      { for (int z=ns[2]; z<=ns[5]; z++)
-        for (int y=ns[1]; y<=ns[4]; y++)
-          for (int x=ns[0]; x<=ns[3]; x++) {
+      for (int z = ns[2]; z<=ns[5]; ++z)
+        for (int y = ns[1]; y<=ns[4]; ++y)
+          for (int x = ns[0]; x<=ns[3]; ++x) {
             const CImg<> fiber = get_fibertrack(eigen,x,y,z,lmax,dl,famin,cmin);
             if (fiber.width()>lmin) {
               bool valid_fiber = false;
@@ -527,21 +525,21 @@ int main(int argc,char **argv) {
                 fibers.insert(fiber);
               }
             }
-          }}
+          }
 
       std::fprintf(stderr," %u fiber(s) added (total %u).",fibers.size()-N,fibers.size());
     } break;
 
     // Clear fiber bundle
     //-------------------
-    case cimg::keyC: {
+    case cimg::keyC : {
       std::fprintf(stderr,"\n- Fibers removed.");
       fibers.assign();
     } break;
 
     // Save fibers
     //-------------
-    case cimg::keyS: {
+    case cimg::keyS : {
       fibers.save("fibers.cimg");
       std::fprintf(stderr,"\n- Fibers saved.");
     } break;
