@@ -46,9 +46,9 @@
 */
 
 #ifndef gmic_version
-#define gmic_version 1336
+#define gmic_version 1390
 
-// Define environement variables.
+// Define environment variables.
 #ifndef cimg_verbosity
 #define cimg_verbosity 1
 #endif
@@ -63,16 +63,35 @@
 // Define the structures used to store images and image lists.
 // You image data must be copied in such structures before
 // calling the G'MIC interpreter.
-#if defined(cimg_build) || defined(gmic_build)
+#ifdef cimg_location
 #include cimg_location
+#if cimg_OS==2
+#include <process.h>
+#endif
+
+// Define some special character codes used for replacement in double quoted strings.
+const char _dollar = 23, _ampersand = 24, _tilde = 25, _lbrace = 26, _rbrace = 28, _comma = 29, _dquote = 30, _arobace = 31;
+
+// Replace special characters in a string.
+inline char *gmic_strreplace(char *const str) {
+  for (char *s = str ; *s; ++s) {
+    const char c = *s;
+    if (c<' ') *s = c==_ampersand?'&':c==_tilde?'~':c==_lbrace?'{':c==_rbrace?'}':c==_comma?',':
+                 c==_dquote?'\"':c==_arobace?'@':c;
+  }
+  return str;
+}
+
 #else
 #include <cstdio>
 #include <cstring>
 
+#ifndef cimg_version
 namespace cimg_library {
 
   // Define the G'MIC image class.
   //------------------------------
+
   template<typename T> struct CImg {
     unsigned int _width;       // Number of image columns (dimension along the X-axis).
     unsigned int _height;      // Number of image lines (dimension along the Y-axis)
@@ -90,31 +109,30 @@ namespace cimg_library {
   // Define the G'MIC image list class.
   //-----------------------------------
   template<typename T> struct CImgList {
-    unsigned int _size;           // Number of images in the list.
-    unsigned int _allocated_size; // Allocated items in the list (must be >size and equal to a power of 2).
-    CImg<T> *_data;               // Pointer to the first image of the list.
+    unsigned int _width;           // Number of images in the list.
+    unsigned int _allocated_width; // Allocated items in the list (must be >size and equal to a power of 2).
+    CImg<T> *_data;                // Pointer to the first image of the list.
 
-    ~CImgList();                                       // Destructor.
-    CImgList():_size(0),_allocated_size(0),_data(0) {} // Empty constructor.
-    CImgList<T>& assign(const unsigned int n);         // Use to allocate a new image list with specified dimension.
+    ~CImgList();                                         // Destructor.
+    CImgList():_width(0),_allocated_width(0),_data(0) {} // Empty constructor.
+    CImgList<T>& assign(const unsigned int n);           // Use to allocate a new image list with specified dimension.
   };
 }
-#endif
+#endif  // #ifndef cimg_version
+#endif  // #ifdef cimg_location
 #define gmic_image cimg_library::CImg
 #define gmic_list cimg_library::CImgList
 
 // Define the G'MIC exception class.
 //----------------------------------
 struct gmic_exception {
-  char _message[16384];
-  char _command[1024];
-  gmic_exception() { *_message = 0; *_command = 0; }
+  gmic_image<char> _command, _message;
   gmic_exception(const char *const command, const char *const message) {
-    if (command) std::strcpy(_command,command); else *_command = 0;
-    if (message) std::strcpy(_message,message); else *_message = 0;
+    if (command) { _command.assign(std::strlen(command)+1,1,1,1); std::strcpy(_command._data,command); }
+    if (message) { _message.assign(std::strlen(message)+1,1,1,1); std::strcpy(_message._data,message); }
   }
-  const char *what()    const { return _message; }   // Give the error message returned by the G'MIC interpreter.
-  const char *command() const { return _command; }
+  const char *what()    const { return _message._data?_message._data:""; }  // Give the error message returned by the G'MIC interpreter.
+  const char *command() const { return _command._data?_command._data:""; }
 };
 
 // Define the G'MIC interpreter class.
@@ -125,17 +143,18 @@ struct gmic {
 #if cimg_display!=0
   cimg_library::CImgDisplay instant_window[10];
 #endif
-  gmic_list<char> command_names, command_definitions, scope, stack;
+  gmic_list<char> command_names, command_definitions, scope;
   gmic_list<unsigned int> dowhiles, repeatdones;
+  gmic_image<unsigned char> background3d, light3d;
+  gmic_image<float> pose3d;
+  gmic_image<char> status;
   float focale3d, light3d_x, light3d_y, light3d_z, specular_light3d, specular_shine3d, _progress, *progress;
-  bool is_released, is_debug, is_start, is_double3d, check_elif;
+  bool is_released, is_debug, is_start, is_quit, is_double3d, is_default_type, check_elif;
   int verbosity, render3d, renderd3d;
   volatile int _cancel, *cancel;
-  unsigned char background3d[3];
-  unsigned int position;
-  char *tmpstr, *_tmpstr;
+  unsigned int nb_carriages, position;
 
-  // Constructors - Destructors.
+  // Constructors.
   // Use them to run the G'MIC interpreter from your C++ source.
   gmic(const char *const command_line, const char *const custom_commands=0, const bool default_commands=true,
        float *const p_progress=0, int *const p_cancel=0);
@@ -145,98 +164,110 @@ struct gmic {
   template<typename T> gmic(const char *const command_line, gmic_list<T>& images,
                             const char *const custom_commands=0, const bool default_commands=true,
                             float *const p_progress=0, int *const p_cancel=0);
-  ~gmic();
 
   // All functions below should be considered as 'private' and thus, should not be used
   // in your own C++ source code. Use them at your own risk.
   gmic& add_commands(const char *const data_commands);
   gmic& add_commands(std::FILE *const file);
-  gmic_image<char> scope2string() const;
-  gmic_image<char> scope2string(const gmic_image<unsigned int>& scope_selection) const;
+  gmic_image<char> scope2string(const bool is_last_slash=true) const;
+  gmic_image<char> scope2string(const gmic_image<unsigned int>& scope_selection,
+                                const bool is_last_slash=true) const;
 
   gmic& assign(const char *const custom_commands=0, const bool default_commands=true,
                float *const p_progress=0, int *const p_cancel=0);
 
   gmic_image<unsigned int> selection2cimg(const char *const string, const unsigned int indice_max,
-                                          const char *const command, const bool is_selection) const;
+                                          const gmic_list<char>& labels,
+                                          const char *const command, const bool is_selection,
+                                          const bool allow_new_label, gmic_image<char>& new_label);
 
-  gmic_list<char> command_line_to_CImgList(const char *const command_line) const;
+  gmic_list<char> command_line_to_CImgList(const char *const command_line);
 
   char *selection2string(const gmic_image<unsigned int>& selection,
-                         const gmic_list<char>& filenames,
+                         const gmic_list<char>& images_labels,
                          const bool display_selection) const;
 
   template<typename T>
-  bool substitute_item(const char *const source, char *const destination, const gmic_list<T>& images,
-                       const gmic_list<char>& filenames, const gmic_list<unsigned int>& repeatdones) const;
+  gmic_image<char> substitute_item(const char *const source,
+                                   gmic_list<T>& images, gmic_list<char>& images_labels,
+                                   const gmic_list<char>& stack, const gmic_list<char>& stack_labels);
 
-  const gmic& print(const char *format, ...) const;
+  gmic& print(const char *format, ...);
   template<typename T>
-  const gmic& print(const gmic_list<T>& list, const char *format, ...) const;
+  gmic& print(const gmic_list<T>& list, const char *format, ...);
   template<typename T>
-  const gmic& print(const gmic_list<T>& list, const gmic_image<unsigned int>& scope_selection, const char *format, ...) const;
+  gmic& print(const gmic_list<T>& list, const gmic_image<unsigned int>& scope_selection, const char *format, ...);
 
-  const gmic& warning(const char *format, ...) const;
+  gmic& warning(const char *format, ...);
   template<typename T>
-  const gmic& warning(const gmic_list<T>& list, const char *format, ...) const;
+  gmic& warning(const gmic_list<T>& list, const char *format, ...);
   template<typename T>
-  const gmic& warning(const gmic_list<T>& list, const gmic_image<unsigned int>& scope_selection, const char *format, ...) const;
+  gmic& warning(const gmic_list<T>& list, const gmic_image<unsigned int>& scope_selection, const char *format, ...);
 
-  const gmic& error(const char *format, ...) const;
+  gmic& error(const char *format, ...);
   template<typename T>
-  const gmic& error(const gmic_list<T>& list, const char *format, ...) const;
+  gmic& error(const gmic_list<T>& list, const char *format, ...);
   template<typename T>
-  const gmic& error(const gmic_list<T>& list, const gmic_image<unsigned int>& scope_selection, const char *format, ...) const;
+  gmic& error(const char *const command, const gmic_list<T>& list, const char *format, ...);
   template<typename T>
-  const gmic& _arg_error(const gmic_list<T>& list, const char *const command, const char *const argument) const;
+  gmic& error(const gmic_list<T>& list, const gmic_image<unsigned int>& scope_selection, const char *format, ...);
+  template<typename T>
+  gmic& _arg_error(const gmic_list<T>& list, const char *const command, const char *const argument);
 
-  const gmic& debug(const char *format, ...) const;
+  gmic& debug(const char *format, ...);
   template<typename T>
-  const gmic& debug(const gmic_list<T>& list, const char *format, ...) const;
+  gmic& debug(const gmic_list<T>& list, const char *format, ...);
 
   template<typename T>
   gmic& display_images(const gmic_list<T>& images,
-                       const gmic_list<char>& filenames,
+                       const gmic_list<char>& images_labels,
                        const gmic_image<unsigned int>& selection);
   template<typename T>
   gmic& display_plots(const gmic_list<T>& images,
-                      const gmic_list<char>& filenames,
+                      const gmic_list<char>& images_labels,
                       const gmic_image<unsigned int>& selection,
                       const unsigned int plot_type, const unsigned int vertex_type,
                       const double xmin, const double xmax,
                       const double ymin, const double ymax);
   template<typename T>
   gmic& display_objects3d(const gmic_list<T>& images,
-                          const gmic_list<char>& filenames,
+                          const gmic_list<char>& images_labels,
                           const gmic_image<unsigned int>& selection);
 
   template<typename T>
   gmic& parse(const gmic_list<char>& command_line, unsigned int& position,
-              gmic_list<T> &images, gmic_list<char> &filenames);
+              gmic_list<T> &images, gmic_list<char> &images_labels,
+              gmic_list<char>& stack, gmic_list<char>& stack_labels);
   gmic& parse_bool(const gmic_list<char>& command_line, unsigned int& position,
-                   gmic_list<bool>& images, gmic_list<char> &filename);
+                   gmic_list<bool>& images, gmic_list<char> &filename,
+                   gmic_list<char>& stack,gmic_list<char>& stack_labels);
   gmic& parse_uchar(const gmic_list<char>& command_line, unsigned int& position,
-                    gmic_list<unsigned char>& images, gmic_list<char> &filenames);
+                    gmic_list<unsigned char>& images, gmic_list<char> &images_labels,
+                    gmic_list<char>& stack, gmic_list<char>& stack_labels);
   gmic& parse_char(const gmic_list<char>& command_line, unsigned int& position,
-                   gmic_list<char>& images, gmic_list<char> &filenames);
+                   gmic_list<char>& images, gmic_list<char> &images_labels,
+                   gmic_list<char>& stack, gmic_list<char>& stack_labels);
   gmic& parse_ushort(const gmic_list<char>& command_line, unsigned int& position,
-                     gmic_list<unsigned short>& images, gmic_list<char> &filenames);
+                     gmic_list<unsigned short>& images, gmic_list<char> &images_labels,
+                     gmic_list<char>& stack, gmic_list<char>& stack_labels);
   gmic& parse_short(const gmic_list<char>& command_line, unsigned int& position,
-                    gmic_list<short>& images, gmic_list<char> &filenames);
+                    gmic_list<short>& images, gmic_list<char> &images_labels,
+                    gmic_list<char>& stack, gmic_list<char>& stack_labels);
   gmic& parse_uint(const gmic_list<char>& command_line, unsigned int& position,
-                   gmic_list<unsigned int>& images, gmic_list<char> &filenames);
+                   gmic_list<unsigned int>& images, gmic_list<char> &images_labels,
+                   gmic_list<char>& stack, gmic_list<char>& stack_labels);
   gmic& parse_int(const gmic_list<char>& command_line, unsigned int& position,
-                  gmic_list<int>& images, gmic_list<char> &filenames);
+                  gmic_list<int>& images, gmic_list<char> &images_labels,
+                  gmic_list<char>& stack, gmic_list<char>& stack_labels);
   gmic& parse_float(const gmic_list<char>& command_line, unsigned int& position,
-                    gmic_list<float>& images, gmic_list<char> &filenames);
+                    gmic_list<float>& images, gmic_list<char> &images_labels,
+                    gmic_list<char>& stack, gmic_list<char>& stack_labels);
   gmic& parse_double(const gmic_list<char>& command_line, unsigned int& position,
-                     gmic_list<double>& images, gmic_list<char> &filenames);
+                     gmic_list<double>& images, gmic_list<char> &images_labels,
+                     gmic_list<char>& stack, gmic_list<char>& stack_labels);
 
 }; // End of the 'gmic' class.
 
-// Define some character codes used for replacement in double quoted strings.
-const char _lbrace = 26, _rbrace = 28, _comma = 29, _dquote = 30;
-
 #endif
 
 // Local Variables:
