@@ -110,11 +110,11 @@ int main(int argc,char **argv) {
         // Create and display the image of the intensity profile
         CImg<unsigned char>(draw_disp.width(),draw_disp.height(),1,3,255).
           draw_grid(-50*100.0f/image.width(),-50*100.0f/256,0,0,false,true,black,0.2f,0xCCCCCCCC,0xCCCCCCCC).
-          draw_axis(0,image.width()-1.0f,255.0f,0.0f,black).
+          draw_axes(0,image.width()-1.0f,255.0f,0.0f,black).
           draw_graph(image.get_shared_line(y,0,0),red,1,1,0,255,1).
           draw_graph(image.get_shared_line(y,0,1),green,1,1,0,255,1).
           draw_graph(image.get_shared_line(y,0,2),blue,1,1,0,255,1).
-          draw_text(30,5,"Pixel (%d,%d)={%d %d %d}",black,0,1,11,
+          draw_text(30,5,"Pixel (%d,%d)={%d %d %d}",black,0,1,13,
                     main_disp.mouse_x(),main_disp.mouse_y(),val_red,val_green,val_blue).
           draw_line(xl,0,xl,draw_disp.height()-1,black,0.5f,hatch=cimg::rol(hatch)).
           display(draw_disp);
