@@ -117,7 +117,7 @@
     CImg<unsigned char> img(640,400,1,3);        // Define a 640x400 color image with 8 bits per color component.
     img.fill(0);                                 // Set pixel values to 0 (color : black)
     unsigned char purple[] = { 255,0,255 };      // Define a purple color
-    img.draw_text("Hello World",100,100,purple); // Draw a purple "Hello world" at coordinates (100,100).
+    img.draw_text(100,100,"Hello World",purple); // Draw a purple "Hello world" at coordinates (100,100).
     img.display("My first CImg code");           // Display the image in a display window.
     return 0;
   }
@@ -131,7 +131,7 @@
 
   int main() {
     const unsigned char purple[] = { 255,0,255 };
-    CImg<unsigned char>(640,400,1,3,0).draw_text("Hello World",100,100,purple).display("My first CImg code");
+    CImg<unsigned char>(640,400,1,3,0).draw_text(100,100,"Hello World",purple).display("My first CImg code");
     return 0;
   }
   \endcode
@@ -503,29 +503,17 @@
   This will disable the display support, since the %CImg Library doesn't contain the necessary code to display
   images on systems other than X11 or Windows GDI.
 
-  - \b \c cimg_color_terminal : This variable tells the library if the system terminal has VT100 color capabilities.
+  - \b \c cimg_use_vt100 : This variable tells the library if the system terminal has VT100 color capabilities.
   It can be \e defined or \e not \e defined. Define this variable to get colored output on your terminal,
   when using the %CImg Library.
 
-  - \b \c cimg_debug : This variable defines the level of run-time debug messages that will be displayed by
+  - \b \c cimg_verbosity : This variable defines the level of run-time debug messages that will be displayed by
   the %CImg Library. It can be set to 0 (no debug messages), 1 (normal debug messages displayed on
   standard error), 2 (normal debug messages displayed in modal windows, which is
   the default value), or 3 (high debug messages). Note that setting this value to 3 may slow down your
   program since more debug tests are made by the library (particularly to check if pixel access is made outside
   image boundaries). See also CImgException to better understand how debug messages are working.
 
-  - \b \c cimg_convert_path : This variables tells the library where the ImageMagick's \e convert tool is located.
-  Setting this variable should not be necessary if ImageMagick is installed on a standard directory, or
-  if \e convert is in your system PATH variable. This macro should be defined only if the ImageMagick's
-  \e convert tool is not found automatically, when trying to read compressed image format (GIF,PNG,...).
-  See also cimg_library::CImg::get_load_convert() and cimg_library::CImg::save_convert() for more informations.
-
-  - \b \c cimg_temporary_path : This variable tells the library where it can find a directory to store
-  temporary files. Setting this variable should not be necessary if you are running on a standard system.
-  This macro should be defined only when troubles are encountered when trying to read
-  compressed image format (GIF,PNG,...).
-  See also cimg_library::CImg::get_load_convert() and cimg_library::CImg::save_convert() for more informations.
-
   - \b \c cimg_plugin : This variable tells the library to use a plugin file to add features to the CImg<T> class.
   Define it with the path of your plugin file, if you want to add member functions to the CImg<T> class,
   without having to modify directly the \c "CImg.h" file. An include of the plugin file is performed in the CImg<T>
@@ -540,11 +528,6 @@
 **/
 /*@}*/
 
-/*-----------------------------------
-
-   Using drawing functions
-
-  -------------------------------------*/
 
 /** \addtogroup cimg_visual2005 How to use CImg library with Visual C++ 2005 Express Edition ?. */
 /*@{*/
@@ -599,10 +582,10 @@
     const unsigned char red[] = { 255,0,0 }, green[] = { 0,255,0 }, blue[] = { 0,0,255 };
     image.blur(2.5);
     CImgDisplay main_disp(image,"Click a point"), draw_disp(visu,"Intensity profile");
-    while (!main_disp.is_closed && !draw_disp.is_closed) {
+    while (!main_disp.is_closed() && !draw_disp.is_closed()) {
       main_disp.wait();
-      if (main_disp.button && main_disp.mouse_y>=0) {
-        const int y = main_disp.mouse_y;
+      if (main_disp.button() && main_disp.mouse_y()>=0) {
+        const int y = main_disp.mouse_y();
         visu.fill(0).draw_graph(image.get_crop(0,y,0,0,image.width()-1,y,0,0),red,1,1,0,255,0);
         visu.draw_graph(image.get_crop(0,y,0,1,image.width()-1,y,0,1),green,1,1,0,255,0);
         visu.draw_graph(image.get_crop(0,y,0,2,image.width()-1,y,0,2),blue,1,1,0,255,0).display(draw_disp);
@@ -643,15 +626,15 @@
   \code CImgDisplay main_disp(image,"Click a point"), draw_disp(visu,"Intensity profile"); \endcode
   Creation of two display windows, one for the input image image, and one for the image visu which will be display intensity profiles.
   By default, CImg displays handles events (mouse,keyboard,..). On Windows, there is a way to create fullscreen displays.
-  \code while (!main_disp.is_closed && !draw_disp.is_closed) { \endcode
+  \code while (!main_disp.is_closed() && !draw_disp.is_closed()) { \endcode
   Enter the event loop, the code will exit when one of the two display windows is closed.
   \code main_disp.wait(); \endcode
   Wait for an event (mouse, keyboard,..) in the display window \c main_disp.
-  \code if (main_disp.button && main_disp.mouse_y>=0) { \endcode
+  \code if (main_disp.button() && main_disp.mouse_y()>=0) { \endcode
   Test if the mouse button has been clicked on the image area.
   One may distinguish between the 3 different mouse buttons,
   but in this case it is not necessary
-  \code const int y = main_disp.mouse_y; \endcode
+  \code const int y = main_disp.mouse_y(); \endcode
   Get the image line y-coordinate that has been clicked.
   \code visu.fill(0).draw_graph(image.get_crop(0,y,0,0,image.width()-1,y,0,0),red,1,0,256,0); \endcode
   This line illustrates the pipeline property of most of the CImg class functions. The first function <tt>fill(0)</tt> simply sets
@@ -1019,7 +1002,7 @@
   is stored in memory exactly as a 3D scalar image having a depth=3, meaning that when you are dealing with 2D color images, you can write 'img(x,y,k)'
   instead of 'img(x,y,0,k)' to access the kth channel of the (x,y) pixel. More generally, if you have one dimension that is 1 in
   your image, you can just skip it in the call to the operator(). Similarly, values of a column vector stored as an image with
-  width=depth=dim=1 can be accessed by 'img(y)' instead of 'img(0,y)'. This is very convenient.
+  width=depth=spectrum=1 can be accessed by 'img(y)' instead of 'img(0,y)'. This is very convenient.
 
   Another cool thing is that it allows you to work easily with 'shared' images. A shared image is a CImg<T> instance that shares
   its memory with another one (the 'base' image). Destroying a shared image does nothing in fact. Shared images is a convenient
